Crate namada_core

Crate namada_core 

The core Namada types, helpers and re-exported dependencies.

Re-exports

pub use masp_primitives;

Modules

address
Implements transparent addresses as described in Accounts Addresses.
arith
Arithmetics helpers
booleans
Boolean related functionality.
borsh
Borsh binary encoding (re-exported) from official crate with custom ext.
bytes
Bytes hex formatting
chain
Chain related data types
collections
Re-exports of collection types.
dec
A non-negative fixed precision decimal type.
eth_abi
This module defines encoding methods compatible with Ethereum smart contracts.
eth_bridge_pool
The necessary type definitions for the contents of the Ethereum bridge pool
ethereum_events
Types representing data intended for Namada via Ethereum events
ethereum_structs
Ethereum bridge struct re-exports and types to do with ethereum.
hash
Types for working with 32 bytes hashes.
hints
Compiler hints, to improve the performance of certain operations.
ibc
IBC-related data types
internal
Shared internal types between the host env and guest (wasm).
keccak
This module is for hashing Namada types using the keccak256 hash function in a way that is compatible with smart contracts on Ethereum.
key
Cryptographic keys
masp
MASP types
parameters
Protocol parameters types
storage
Storage types
string_encoding
Namada’s standard string encoding for public types.
tendermint
Re-export of tendermint v0.37
tendermint_proto
Re-export of tendermint-proto v0.37
time
Types for dealing with time and durations.
token
A basic fungible token
uint
An unsigned 256 integer type. Used for, among other things, the backing type of token amounts.
validity_predicate
Types that are used in validity predicates.
voting_power
This module contains types related with validator voting power calculations.

Macros

impl_display_and_from_str_via_format
Implement std::fmt::Display and std::str::FromStr via Format.

Enums

DecodeError

Functions

consensus_version
Get the current consensus version
decode
Decode a value with borsh
encode
Encode a value with borsh