The core Namada types, helpers and re-exported dependencies.
Re-exports
pub use masp_primitives;
Modules
- address
- Implements transparent addresses as described in Accounts Addresses.
- arith
- Arithmetics helpers
- booleans
- Boolean related functionality.
- borsh
- Borsh binary encoding (re-exported) from official crate with custom ext.
- bytes
- Bytes hex formatting
- chain
- Chain related data types
- collections
- Re-exports of collection types.
- dec
- A non-negative fixed precision decimal type.
- eth_abi
- This module defines encoding methods compatible with Ethereum smart contracts.
- eth_
bridge_ pool - The necessary type definitions for the contents of the Ethereum bridge pool
- ethereum_
events - Types representing data intended for Namada via Ethereum events
- ethereum_
structs - Ethereum bridge struct re-exports and types to do with ethereum.
- hash
- Types for working with 32 bytes hashes.
- hints
- Compiler hints, to improve the performance of certain operations.
- ibc
- IBC-related data types
- internal
- Shared internal types between the host env and guest (wasm).
- keccak
- This module is for hashing Namada types using the keccak256 hash function in a way that is compatible with smart contracts on Ethereum.
- key
- Cryptographic keys
- masp
- MASP types
- parameters
- Protocol parameters types
- storage
- Storage types
- string_
encoding - Namada’s standard string encoding for public types.
- tendermint
- Re-export of tendermint v0.37
- tendermint_
proto - Re-export of tendermint-proto v0.37
- time
- Types for dealing with time and durations.
- token
- A basic fungible token
- uint
- An unsigned 256 integer type. Used for, among other things, the backing type of token amounts.
- validity_
predicate - Types that are used in validity predicates.
- voting_
power - This module contains types related with validator voting power calculations.
Macros
- impl_
display_ and_ from_ str_ via_ format - Implement
std::fmt::Displayandstd::str::FromStrviaFormat.
Enums
Functions
- consensus_
version - Get the current consensus version
- decode
- Decode a value with borsh
- encode
- Encode a value with borsh